## Annotation Json Schemas
* [General info](#general-info)
* [Setup](#setup)

## General info
This project is SuperAnnotate annotations JSON schema generator.
	
## Setup
```
$ pip install superannotate_schemas
```
